Module error

Module error 

Various errors module.

Structs

BadRequestError
Represents an instance of one of the errors that could be returned on a bad request.
BadRequestField
Represents one of the fields that caused the Bad Request error.
BadRequestResponse
This error represents the error returned by the PocketBase instance in case of a 400 error.

Enums

AuthenticationError
Represents errors that can occur during the authentication process with the PocketBase API.
CreateError
Represents the various errors that can be obtained after a create request.
ImpersonateError
Represents the various errors that can be obtained after a impersonate request.
RequestError
Represents errors when interacting with the PocketBase API.
UpdateError
Represents the various errors that can be obtained after a update request.