CreateError

Enum CreateError 

pub enum CreateError {
    BadRequest(Vec<BadRequestError>),
    Forbidden,
    NotFound,
    Unreachable(String),
    ParseError(String),
    UnexpectedResponse(String),
}
Represents the various errors that can be obtained after a create request.

Variants



BadRequest(Vec<BadRequestError>)

Communication with the PocketBase API was successful, but returned a 400 Bad Request HTTP error response.

Missing required value. PocketBase.



Forbidden

Communication with the PocketBase API was successful, but returned a 403 Forbidden HTTP error response.

You are not allowed to perform this request.



NotFound

Communication with the PocketBase API was successful, but returned a 404 Not Found HTTP error response.

The requested resource wasn’t found. Missing collection context.



Unreachable(String)

Communication with the PocketBase API failed.

This could be caused by an internet outage, an error in the link given to the PocketBase SDK and similar errors.



ParseError(String)

The response could not be parsed into the expected data structure.



UnexpectedResponse(String)

An unexpected error occurred. The response from the PocketBase instance API was unexpected. If you think its an error, please open an issue on GitHub.