ImpersonateError

Enum ImpersonateError 

pub enum ImpersonateError {
    BadRequest,
    Unauthorized,
    Forbidden,
    NotFound,
    Unreachable(String),
    UnexpectedResponse(String),
}
Represents the various errors that can be obtained after a impersonate request.

Variants



BadRequest

Communication with the PocketBase API was successful, but returned a 400 Bad Request HTTP error response.

The request requires valid record authorization token to be set.



Unauthorized

Communication with the PocketBase API was successful, but returned a 401 Unauthorized HTTP error response.

The request requires valid record authorization token.



Forbidden

Communication with the PocketBase API was successful, but returned a 403 Forbidden HTTP error response.

The authorized record is not allowed to perform this action. Are you impersonating a user from a non-superuser account?



NotFound

Communication with the PocketBase API was successful, but returned a 404 Not Found HTTP error response.

The requested resource wasn’t found. The given user id is probably wrong.



Unreachable(String)

Communication with the PocketBase API failed.

This could be caused by an internet outage, an error in the link given to the PocketBase SDK and similar errors.



UnexpectedResponse(String)

The response from the PocketBase instance API was unexpected. If you think its an error, please open an issue on GitHub.