pub enum RequestError {
BadRequest(String),
Unauthorized,
Forbidden,
NotFound,
ParseError(String),
Unreachable,
TooManyRequests,
Unhandled,
}Expand description
Represents errors when interacting with the PocketBase API.
This enum provides a set of error types that may occur during API requests, each indicating a specific issue encountered.
Variants
BadRequest(String)
Communication with the PocketBase API was successful,
but returned a 400 Bad Request HTTP error response.
Your request may be missing fields or its content doesn’t match what PocketBase expects to receive.
Communication with the PocketBase API was successful,
but returned a 401 Unauthorized HTTP error response.
The request may require an Authorization Token.
Forbidden
Communication with the PocketBase API was successful,
but returned a 403 Forbidden HTTP error response.
The authenticated user may not have permissions for this interaction.
NotFound
Communication with the PocketBase API was successful,
but returned a 404 Not Found HTTP error response.
ParseError(String)
The response could not be parsed into the expected data structure.
Unreachable
The PocketBase API interaction timed out. It may be offline.
TooManyRequests
Too many requests were sent to the API.
The server is rate limiting requests. Wait before retrying.
Unhandled
Unhandled error.
Usually emitted when something unexpected happened, and isn’t handled correctly by this crate.