pub struct BadRequestField {
pub code: String,
pub message: String,
}Expand description
Represents one of the fields that caused the Bad Request error.
Fields
code: StringError code (example: validation_required).
message: StringA text explaining in a readable way what this error is.