Various errors module.
Structs
- BadRequest
Error - Represents an instance of one of the errors that could be returned on a bad request.
- BadRequest
Field - Represents one of the fields that caused the Bad Request error.
- BadRequest
Response - This error represents the error returned by the
PocketBaseinstance in case of a 400 error.
Enums
- Authentication
Error - Represents errors that can occur during the authentication process with the
PocketBaseAPI. - Create
Error - Represents the various errors that can be obtained after a
createrequest. - Impersonate
Error - Represents the various errors that can be obtained after a
impersonaterequest. - Request
Error - Represents errors when interacting with the
PocketBaseAPI. - Update
Error - Represents the various errors that can be obtained after a
updaterequest.